@@ -5,7 +5,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.036_01';
+our $VERSION = '0.037_01';
 
 1;
 
@@ -54,6 +54,10 @@ parse. If this functionality is retracted and the syntax used for
 something else, C<PPIx::Regexp> will forget completely about regex
 character sets.
 
+At some point, the documentation started calling these "Extended
+Bracketed Character Classes", and documenting them in
+L<perlrecharclass|perlrecharclass>.
+
 =head1 METHODS
 
 This class supports no public methods over and above those supported by
@@ -70,7 +74,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2014 by Thomas R. Wyant, III
+Copyright (C) 2013-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
